
/* -----------------------------------------------------------------------------
Data preparation
- compute a large dataset. 

Original datasets can be found here: https://www.lissdata.nl/access-data
On May 19 2021, a few datasets are publically available, while other will 
 be in the future. 
 
 
We use: 

 - Background Variables: wave 2016 January to 2020 September
 - Time Use and Consumption: wave 7
 - Effects of the outbreak of COVID-19: part1 to part 5
 - Work and Schooling: wave 9 to wave 13

 
----------------------------------------------------------------------------- */

*----------------------*
* Background variables
*----------------------*

* import data
use "$raw_local/data/001-background-variables/avars_202010_EN_1.0p.dta", clear

forv m = 1(1)9 {
	append using  "$raw_local/data/001-background-variables/avars_20200`m'_EN_1.0p.dta"
	append using  "$raw_local/data/001-background-variables/avars_20190`m'_EN_1.0p.dta"
}
forv m = 10(1)12 {
	append using  "$raw_local/data/001-background-variables/avars_2019`m'_EN_1.0p.dta"
}
forv y = 2016(1)2018 {
	forv m = 1(1)9 {
		append using  "$raw_local/data/001-background-variables/avars_`y'0`m'_EN_1.0p.dta"
	}
	forv m = 10(1)12 {
		append using  "$raw_local/data/001-background-variables/avars_`y'`m'_EN_1.0p.dta"
	}
}


* identify children below 20
replace positie = 8 if positie == 5 & leeftijd>=20

preserve
keep if positie ==5 
rename leeftijd age_child 
gen inschool_child = oplzon<=6 if oplzon!=. & age_child<=18
keep nohouse_encr wave inschool_child age_child
sort nohouse_encr wave age_child
bysort nohouse_encr wave: gen i =_n
reshape wide inschool_child age_child, i(nohouse_encr wave) j(i)
gen age_youngest_child = age_child1
tempfile children 
save `children', replace
restore

* keep adults
keep if positie != 5 

* merge parents and children
preserve
keep if positie <=3
merge m:1 nohouse_encr wave using `children'
gen inhouse_child = _merge ==3 
drop _merge 

tempfile parents 
save `parents'
restore 

keep if positie >3
gen inhouse_child = 0
append using `parents'

* rename variables
rename geslacht gender
rename leeftijd age 
rename nettoink_f  income_net
rename brutoink_f income_gross
rename brutohh_f hhincome_gross
rename nettohh_f hhincome_net

* create variables
gen year = real(substr(string(wave),1,4))
gen month = real(substr(string(wave),5,6))
gen married = (woonvorm == 2 | woonvorm == 3) if woonvorm !=.
gen hasjob = belbezig<=3 if belbezig!=.
gen takecarehk = belbezig==8 if belbezig!=.
gen unemployed = belbezig>=4 &  belbezig<=5 if belbezig!=.
gen notin_LF = belbezig>=6 if belbezig!=.
gen education = oplmet if oplmet<=6 
replace education = 0 if  oplmet>=8 & oplmet<=9

tempfile main 
save `main'

*----------------------*
* time use variables
*----------------------*

* import data
use "$raw_local/data/034-time-use-and-consumption/wave-7/L_consumption_w7_3.0p.dta", clear

* labels
keep nomem_encr maandnr v1*
forv t = 1(1)2 {
	local time = "hours:"
	if `t'==2 local time = "mins:"
	label var v1q1_v1col`t'  "`time' paid work at the normal workplace but not at home"
	label var v1q1a_v1col`t' "`time' if no kids, paid work at home / home office"
	label var v1q1b_v1col`t' "`time' paid work at home, while at the same time I am also responsible for the care of one or more children"
	label var v1q1c_v1col`t' "`time' paid work from home, while I am not also responsible for caring for one or more children"
	label var v1q2_v1col`t' "`time' commuting to work"
	label var v1q5a_v1col`t' "`time' home schooled with children in your household"
	label var v1q5_v1col`t' "`time' other activities with children in your household"
	label var v1q6_v1col`t' "`time' assistance to others (parents or in-laws, other relatives or non-relatives)"
	label var v1q3_v1col`t' "`time' housework"
	label var v1q9_v1col`t' "`time' sleep and rest"
	label var v1q10_v1col`t' "`time' your own (additional) training (online)" 
	label var v1q15_v1col`t' "`time' leisure activities alone" 
	label var v1q16_v1col`t' "`time' leisure activities online with others"
	label var v1q12_v1col`t' "`time' leisure activities with others"
	label var v1q13_v1col`t' "`time' other activities not mentioned above"
}

* clean
foreach v of varlist v1* {
	replace `v'=0 if `v'==.
}

* create variables
gen year = real(substr(string(maandnr),1,4))
gen month = real(substr(string(maandnr),5,6))

gen  hours_h_wok = v1q1a_v1col1+ v1q1a_v1col2/60 + v1q1c_v1col1+ v1q1c_v1col2/60
gen  hours_h_wk = v1q1b_v1col1+ v1q1b_v1col2/60 
gen pct_hours_h_wk = hours_h_wk /(hours_h_wok+hours_h_wk)*100
gen pct_hours_wk = hours_h_wk /(hours_h_wok+hours_h_wk+v1q1_v1col1+v1q1_v1col2/60)*100
gen hours_tu = hours_h_wok+hours_h_wk+v1q1_v1col1+v1q1_v1col2/60
gen hours_h_tu = hours_h_wok+hours_h_wk
gen tu_module = 1 

keep year month nomem_encr hours*  pct*  tu_module
tempfile timeuse
save `timeuse', replace

*----------------------*
* corona study
*----------------------*

*import data
use "$raw_local/data/xyx-corona-questionnaire/wave-5/L_CoronavirusImpact_wave5_3p.dta", clear
append using  "/$raw_local/data/xyx-corona-questionnaire/wave-4/L_CoronavirusImpact_wave4_4p.dta"
append using   "$raw_local/data/xyx-corona-questionnaire/wave-3/L_CoronavirusImpact_wave3_4p.dta"

* create variables
keep nomem_encr maandnr q14* work_perc EmploymentStatus
rename q14b_q14werk hours_wp 
rename q14b_q14thuis hours_h
replace hours_wp  = 0 if EmploymentStatus>2 & EmploymentStatus!=.
replace hours_h  = 0 if EmploymentStatus>2 & EmploymentStatus!=.
tempfile lwaves 
save `lwaves', replace 

*import data
use  "$raw_local/data/xyx-corona-questionnaire/wave-2/L_CoronavirusImpact_4.0p.dta", clear

* create variables
keep nomem_encr maandnr q14* q13 p_q13
gen hours_wp = q14b_1_q14werk_1
replace hours_wp = q14c_q14werk if hours_wp==. & q14c_q14werk!=.
gen hours_h = q14b_1_q14thuis_1
replace hours_h = q14c_q14thuis if hours_h==. & q14c_q14thuis!=.
gen EmploymentStatusMarch = (q13 == 1 | q13 == 2 | p_q13 == 1 | p_q13 == 2) if q13!=. | p_q13!=.

keep nomem_encr maandnr hours* EmploymentStatusMarch
tempfile awaves 
save `awaves', replace 

*import data
use  "$raw_local/data/xyx-corona-questionnaire/wave-1/L_CoronavirusImpact_3p.dta", clear

* create variables
keep nomem_encr maandnr q14* q10 q13
rename q14b hours_wp 
rename q14d hours_h
rename q14a hours_wp_march 
rename q14c hours_h_march 
replace hours_h_march  = 0 if q13!=1 & q13!=2 & q13!=.
replace hours_wp_march  = 0 if q13!=1 & q13!=2 & q13!=.
gen EmploymentStatusMarch = (q13 == 1 | q13 == 2) if q13!=. 

append using `awaves'
append using `lwaves'

*labels
label var hours_wp  "On average, how many hours per week did you work at your workplace in the past seven days?"
label var hours_h "On average, how many hours per week did you work at home in the past seven days?"
label var hours_wp_march "On average, how many hours per week did you work at home in early March?"
label var hours_h_march "On average, how many hours per week did you work at your workplace in early March?"
label var q10 "Would you comply with a curfew?"
label var work_perc "What percentage of your normal work prior to the coronavirus outbreak can you do while working from home?"

*create variables
gen year = real(substr(string(maandnr),1,4))
gen month = real(substr(string(maandnr),5,6))
gen hours_c = hours_wp + hours_h
gen hours_c_march = hours_wp_march + hours_h_march

gen work_essential =  q10==3 if q10!=. & ((hours_c!=0 & hours_c!=.) | (hours_c_march!=0 & hours_c_march!=.) )
gen pct_hours_h = hours_h /(hours_wp+hours_h)*100

keep nomem_encr hours* work_perc work_essential month year pct* EmploymentStatusMarch EmploymentStatus
gen corona_sample = 1
tempfile corona 
save `corona', replace 


*----------------------*
* work and schooling
*----------------------*

*import data
use "$raw_local/data/006-work-and-schooling/wave-13/L_WorkSchooling_wave13_SectorProfHours_03p.dta", clear

*create data
rename cw20m126	hours_contract
rename cw20m127 hours
gen year = real(substr(string(cw19l_m),1,4))
gen month = real(substr(string(cw19l_m),5,6))
rename cw20m402 sector
rename cw20m404 prof
keep nomem_encr sector prof hours_contract hours month year
replace sector = sector +1 // so that english labels match dutch labels
replace prof = prof +1 // so that english labels match dutch labels
gen hours_sample = 1
merge 1:1 nomem_encr month year using `corona'
drop _merge 
tempfile work 
save `work', replace 

*import data
use "$raw_local/data/006-work-and-schooling/wave-12/cw19l_EN_1.1p.dta", clear

*create data
gen year = real(substr(string(cw19l_m),1,4))
gen month = real(substr(string(cw19l_m),5,6))
replace month = 4 if month == 5 // a few survey in may 
rename cw19l127 hours
replace hours = 0  if ~(cw19l088==1 | cw19l102==1 | cw19l089==1 | cw19l091==1 | cw19l092==1 | cw19l103==1) | (cw19l522==1)
replace hours = 0 if  cw19l102==0 & cw19l088==0 // are not currently working
rename cw19l126 hours_contract
rename cw19l402 sector
rename cw19l404 prof
keep nomem_encr sector prof hours_contract hours month year
gen hours_sample = 1
append using `work'
tempfile work 
save `work', replace


*import data
use "$raw_local/data/006-work-and-schooling/wave-11/cw18k_EN_1.0p.dta", clear

*create data
gen year = real(substr(string(cw18k_m),1,4))
gen month = real(substr(string(cw18k_m),5,6))
replace month = 4 if month == 5 // a few survey in may 
rename cw18k127 hours
replace hours = 0  if ~(cw18k088==1 | cw18k102==1 | cw18k089==1 | cw18k091==1 | cw18k092==1 | cw18k103==1) | (cw18k522==1)
replace hours = 0 if  cw18k102==0 & cw18k088==0 // are not currently working
rename cw18k126 hours_contract
rename cw18k402 sector
rename cw18k404 prof
keep nomem_encr sector prof hours_contract hours month year
gen hours_sample = 1
append using `work'
tempfile work 
save `work', replace

*import data
use "$raw_local/data/006-work-and-schooling/wave-10/cw17j_EN_1.0p.dta", clear
gen year = real(substr(string(cw17j_m),1,4))
gen month = real(substr(string(cw17j_m),5,6))
replace month = 4 if month == 5 // a few survey in may 
rename cw17j127 hours
replace hours = 0  if ~(cw17j088==1 | cw17j102==1 | cw17j089==1 | cw17j091==1 | cw17j092==1 | cw17j103==1) | (cw17j522==1)
replace hours = 0 if  cw17j102==0 & cw17j088==0 // are not currently working
rename cw17j126 hours_contract
rename cw17j402 sector
rename cw17j404 prof
keep nomem_encr sector prof hours_contract hours month year
gen hours_sample = 1
append using `work'
tempfile work 
save `work', replace

*import data
use "$raw_local/data/006-work-and-schooling/wave-9/cw16i_EN_1.0p.dta", clear
gen year = real(substr(string(cw16i_m),1,4))
gen month = real(substr(string(cw16i_m),5,6))
replace month = 4 if month == 5 // a few survey in may 
rename cw16i127 hours
replace hours = 0  if ~(cw16i088==1 | cw16i102==1 | cw16i089==1 | cw16i091==1 | cw16i092==1 | cw16i103==1) | (cw16i522==1)
replace hours = 0 if  cw16i102==0 & cw16i088==0 // are not currently working
rename cw16i126 hours_contract
rename cw16i402 sector
rename cw16i404 prof
keep nomem_encr sector prof hours_contract hours month year
gen hours_sample = 1
append using `work'
tempfile work 
save `work', replace


*----------------------*
* merge datasets
*----------------------*

merge 1:1 nomem_encr month year using `main', keep(2 3) nogenerate // some kids (<20) are in the corona dataset 
merge 1:1 nomem_encr month year using `timeuse', keep(1 3) nogenerate // some kids (<20) are in the timeuse dataset 

replace  hours_sample = 0 if  hours_sample == .
replace  corona_sample = 0 if  corona_sample == .

* spouse work 
foreach v in hasjob work_essential {
	bysort nohouse_encr year month : gen tspw0 = `v' if positie == 1
	bysort nohouse_encr year month : gen tspw1 = `v' if positie >1 &  positie <4 
	bysort nohouse_encr year month : egen tspw2 = max(tspw0)
	bysort nohouse_encr year month : egen tspw3 = max(tspw1)
	gen sp`v' = tspw2 if positie >1 &  positie <4 
	replace sp`v' = tspw3 if positie == 1
	drop tspw*
}
rename sphasjob spw
bysort nomem_encr: egen spwe= max(spwork_essential)
drop spwork_essential

* labels 
label define married 0 "single/divorced" 1 "married/cohabiting"
label value married married
label define spw 0 "spouse dosen't work" 1 "spouse works"
label value spw spw
label define spwe 0 "spouse no essential (march20)" 1 "spouse works essential (march20)"
label value spwe spwe

save "$out_dir/dta/NLcrosssecinddataset.dta", replace
